"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setErrorProcessor = void 0;
const react_1 = require("react");
let processErrorGlobal = function errorProcessor(error) {
    return (error === null || error === void 0 ? void 0 : error.message) || '';
};
function setErrorProcessor(fn) {
    processErrorGlobal = fn;
}
exports.setErrorProcessor = setErrorProcessor;
function useError(options) {
    const { processError = processErrorGlobal } = options || {};
    const [errorMessage, setErrorMessage] = (0, react_1.useState)('');
    const [isErrored, setIsErrored] = (0, react_1.useState)(false);
    function resetError() {
        setErrorMessage('');
        setIsErrored(false);
    }
    function setError(error) {
        if (!error)
            return resetError();
        if (typeof error === 'string')
            error = new Error(error);
        const apiError = processError(error);
        setErrorMessage(apiError);
        setIsErrored(true);
    }
    return { error: errorMessage, isErrored, setError, resetError };
}
exports.default = useError;
//# sourceMappingURL=useError.js.map